From 7bf3a344f3ec93be6bc5fb829b6355a1811b18b0 Mon Sep 17 00:00:00 2001
From: tapframe <85391825+tapframe@users.noreply.github.com>
Date: Mon, 12 Jan 2026 00:13:29 +0530
Subject: [PATCH] release: 1.3.5 (33)
---
android/app/build.gradle | 6 +++---
android/app/src/main/res/values/strings.xml | 2 +-
app.json | 8 ++++----
nuvio-source.json | 8 ++++++++
src/screens/SearchScreen.tsx | 2 +-
src/utils/version.ts | 2 +-
6 files changed, 18 insertions(+), 10 deletions(-)
diff --git a/android/app/src/main/res/values/strings.xml b/android/app/src/main/res/values/strings.xml
index 2669e01a2..712939e26 100644
--- a/android/app/src/main/res/values/strings.xml
+++ b/android/app/src/main/res/values/strings.xml
@@ -3,5 +3,5 @@
contain
false
dark
- 1.3.4
+ 1.3.5
\ No newline at end of file
diff --git a/app.json b/app.json
index c5a0502ae..cd3a4140b 100644
--- a/app.json
+++ b/app.json
@@ -2,7 +2,7 @@
"expo": {
"name": "Nuvio",
"slug": "nuvio",
- "version": "1.3.4",
+ "version": "1.3.5",
"orientation": "default",
"backgroundColor": "#020404",
"icon": "./assets/ios/AppIcon.appiconset/Icon-App-60x60@3x.png",
@@ -17,7 +17,7 @@
"ios": {
"supportsTablet": true,
"icon": "./assets/ios/AppIcon.appiconset/Icon-App-60x60@3x.png",
- "buildNumber": "32",
+ "buildNumber": "33",
"infoPlist": {
"NSAppTransportSecurity": {
"NSAllowsArbitraryLoads": true
@@ -51,7 +51,7 @@
"android.permission.WRITE_SETTINGS"
],
"package": "com.nuvio.app",
- "versionCode": 32,
+ "versionCode": 33,
"architectures": [
"arm64-v8a",
"armeabi-v7a",
@@ -97,6 +97,6 @@
"fallbackToCacheTimeout": 30000,
"url": "https://ota.nuvioapp.space/api/manifest"
},
- "runtimeVersion": "1.3.4"
+ "runtimeVersion": "1.3.5"
}
}
\ No newline at end of file
diff --git a/nuvio-source.json b/nuvio-source.json
index 4ad1c7a5f..51d02b3be 100644
--- a/nuvio-source.json
+++ b/nuvio-source.json
@@ -30,6 +30,14 @@
"https://github.com/tapframe/NuvioStreaming/blob/main/screenshots/search-portrait.png?raw=true"
],
"versions": [
+ {
+ "version": "1.3.5",
+ "buildVersion": "33",
+ "date": "2026-01-09",
+ "localizedDescription": "## Update Notes\n\n### ExoPlayer Subtitle Fixes\nThis update mainly focuses on fixing multiple subtitle-related issues in ExoPlayer:\n- Fixed issue where **only the first subtitle index** was being rendered \n- Fixed subtitles **always showing background** due to Android native caption settings \n- Fixed subtitles being **rendered inside the player view** \n- Fixed **subtitle bottom offset** issues \n- Merged PR **#391** by **@saifshaikh1805** \n - Fixes issue **#301**\n\n### KSPlayer Improvements\n- Improved **subtitle behavior** in KSPlayer \n- Merged PR **#394** by **@AdityasahuX07**\n\n### Settings & Persistence\n- Implemented **save and load** functionality for **Discover settings**\n\nThis release improves subtitle rendering accuracy across players and adds better persistence for user preferences.",
+ "downloadURL": "https://github.com/tapframe/NuvioStreaming/releases/download/v1.3.5/app-release.apk",
+ "size": 25700000
+ },
{
"version": "1.3.4",
"buildVersion": "32",
diff --git a/src/screens/SearchScreen.tsx b/src/screens/SearchScreen.tsx
index 3b6a435d0..8d5a67459 100644
--- a/src/screens/SearchScreen.tsx
+++ b/src/screens/SearchScreen.tsx
@@ -61,7 +61,7 @@ const DISCOVER_GENRE_KEY = 'discover_selected_genre';
const SearchScreen = () => {
const { t } = useTranslation();
- const { settings, updateSettings } = useSettings();
+ const { settings } = useSettings();
const navigation = useNavigation>();
const { addToWatchlist, removeFromWatchlist, addToCollection, removeFromCollection, isInWatchlist, isInCollection } = useTraktContext();
const { showSuccess, showInfo } = useToast();
diff --git a/src/utils/version.ts b/src/utils/version.ts
index 3bab47517..232d4534d 100644
--- a/src/utils/version.ts
+++ b/src/utils/version.ts
@@ -1,7 +1,7 @@
// Single source of truth for the app version displayed in Settings
// Update this when bumping app version
-export const APP_VERSION = '1.3.4';
+export const APP_VERSION = '1.3.5';
export function getDisplayedAppVersion(): string {
return APP_VERSION;
diff --git a/android/app/build.gradle b/android/app/build.gradle
index 435a61abd..eeec964d4 100644
--- a/android/app/build.gradle
+++ b/android/app/build.gradle
@@ -95,8 +95,8 @@ android {
applicationId 'com.nuvio.app'
minSdkVersion rootProject.ext.minSdkVersion
targetSdkVersion rootProject.ext.targetSdkVersion
- versionCode 32
- versionName "1.3.4"
+ versionCode 33
+ versionName "1.3.5"
buildConfigField "String", "REACT_NATIVE_RELEASE_LEVEL", "\"${findProperty('reactNativeReleaseLevel') ?: 'stable'}\""
}
@@ -118,7 +118,7 @@ android {
def abiVersionCodes = ['armeabi-v7a': 1, 'arm64-v8a': 2, 'x86': 3, 'x86_64': 4]
applicationVariants.all { variant ->
variant.outputs.each { output ->
- def baseVersionCode = 32 // Current versionCode 32 from defaultConfig
+ def baseVersionCode = 33 // Current versionCode 33 from defaultConfig
def abiName = output.getFilter(com.android.build.OutputFile.ABI)
def versionCode = baseVersionCode * 100 // Base multiplier